summaryrefslogtreecommitdiffstats
path: root/admin/kde.py
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-02-26 14:21:52 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-02-26 14:21:52 -0600
commit58553584297cadf0238c32f8ced67be894829016 (patch)
tree083e3ac8d9e011b486fbbcfe77229e6a54e22d13 /admin/kde.py
parent4675c0929b406c4913c7720f641a6ceaa66cc52a (diff)
downloadkstreamripper-58553584297cadf0238c32f8ced67be894829016.tar.gz
kstreamripper-58553584297cadf0238c32f8ced67be894829016.zip
Rename kde-config to tde-config
Diffstat (limited to 'admin/kde.py')
-rw-r--r--admin/kde.py74
1 files changed, 37 insertions, 37 deletions
diff --git a/admin/kde.py b/admin/kde.py
index 50be00c..5958a27 100644
--- a/admin/kde.py
+++ b/admin/kde.py
@@ -30,7 +30,7 @@ def exists(env):
return True
def detect_kde(env):
""" Detect the qt and kde environment using kde-config mostly """
prefix = env['ARGS'].get('prefix', None)
execprefix = env['ARGS'].get('execprefix', None)
@@ -42,19 +42,19 @@ def detect_kde(env):
qtlibs = env['ARGS'].get('qtlibs', None)
## Detect the kde libraries
- print "Checking for kde-config : ",
- kde_config = os.popen("which kde-config 2>/dev/null").read().strip()
+ print "Checking for tde-config : ",
+ kde_config = os.popen("which tde-config 2>/dev/null").read().strip()
if len(kde_config):
- print GREEN + "kde-config was found" + NORMAL
+ print GREEN + "tde-config was found" + NORMAL
else:
- print RED + "kde-config was NOT found in your PATH"+ NORMAL
+ print RED + "tde-config was NOT found in your PATH"+ NORMAL
print "Make sure kde is installed properly"
print "(missing package tdebase-devel?)"
env.Exit(1)
- env['TDEDIR'] = os.popen('kde-config -prefix').read().strip()
+ env['TDEDIR'] = os.popen('tde-config -prefix').read().strip()
print "Checking for kde version : ",
- kde_version = os.popen("kde-config --version|grep KDE").read().strip().split()[1]
+ kde_version = os.popen("tde-config --version|grep KDE").read().strip().split()[1]
if int(kde_version[0]) != 3 or int(kde_version[2]) < 2:
print RED + kde_version
print RED + "Your kde version can be too old" + NORMAL
@@ -68,7 +68,7 @@ def detect_kde(env):
if qtdir:
print GREEN + "qt is in " + qtdir + NORMAL
else:
- libdir = os.popen('kde-config --expandvars --install lib').read().strip()
+ libdir = os.popen('tde-config --expandvars --install lib').read().strip()
libtdeuiSO = libdir+'/'+getSOfromLA(libdir+'/libtdeui.la')
m = re.search('(.*)/lib/libqt.*', os.popen('ldd '+libtdeuiSO+' | grep libqt').read().strip().split()[2])
if m:
@@ -137,7 +137,7 @@ def detect_kde(env):
env.Exit(1)
print "Checking for the kde includes : ",
- kdeprefix = os.popen("kde-config --prefix").read().strip()
+ kdeprefix = os.popen("tde-config --prefix").read().strip()
if not kdeincludes:
kdeincludes = kdeprefix+"/include/"
if os.path.isfile(kdeincludes + "/klineedit.h"):
@@ -161,40 +161,40 @@ def detect_kde(env):
libdir = execprefix+"/lib"
subst_vars = lambda x: x.replace('${exec_prefix}',execprefix).replace('${datadir}',datadir).replace('${libdir}',libdir)
- env['KDEBIN'] = subst_vars(os.popen('kde-config --install exe').read().strip())
- env['KDEAPPS'] = subst_vars(os.popen('kde-config --install apps').read().strip())
- env['KDEDATA'] = subst_vars(os.popen('kde-config --install data').read().strip())
- env['KDEMODULE']= subst_vars(os.popen('kde-config --install module').read().strip())
- env['KDELOCALE']= subst_vars(os.popen('kde-config --install locale').read().strip())
- env['KDEDOC'] = subst_vars(os.popen('kde-config --install html').read().strip())
- env['KDEKCFG'] = subst_vars(os.popen('kde-config --install kcfg').read().strip())
- env['KDEXDG'] = subst_vars(os.popen('kde-config --install xdgdata-apps').read().strip())
- env['KDEMENU'] = subst_vars(os.popen('kde-config --install apps').read().strip())
- env['KDEMIME'] = subst_vars(os.popen('kde-config --install mime').read().strip())
- env['KDEICONS'] = subst_vars(os.popen('kde-config --install icon').read().strip())
- env['KDESERV'] = subst_vars(os.popen('kde-config --install services').read().strip())
+ env['KDEBIN'] = subst_vars(os.popen('tde-config --install exe').read().strip())
+ env['KDEAPPS'] = subst_vars(os.popen('tde-config --install apps').read().strip())
+ env['KDEDATA'] = subst_vars(os.popen('tde-config --install data').read().strip())
+ env['KDEMODULE']= subst_vars(os.popen('tde-config --install module').read().strip())
+ env['KDELOCALE']= subst_vars(os.popen('tde-config --install locale').read().strip())
+ env['KDEDOC'] = subst_vars(os.popen('tde-config --install html').read().strip())
+ env['KDEKCFG'] = subst_vars(os.popen('tde-config --install kcfg').read().strip())
+ env['KDEXDG'] = subst_vars(os.popen('tde-config --install xdgdata-apps').read().strip())
+ env['KDEMENU'] = subst_vars(os.popen('tde-config --install apps').read().strip())
+ env['KDEMIME'] = subst_vars(os.popen('tde-config --install mime').read().strip())
+ env['KDEICONS'] = subst_vars(os.popen('tde-config --install icon').read().strip())
+ env['KDESERV'] = subst_vars(os.popen('tde-config --install services').read().strip())
else:
# the user has given no prefix, install as a normal kde app
- env['PREFIX'] = os.popen('kde-config --prefix').read().strip()
- env['KDEBIN'] = os.popen('kde-config --expandvars --install exe').read().strip()
- env['KDEAPPS'] = os.popen('kde-config --expandvars --install apps').read().strip()
- env['KDEDATA'] = os.popen('kde-config --expandvars --install data').read().strip()
- env['KDEMODULE']= os.popen('kde-config --expandvars --install module').read().strip()
- env['KDELOCALE']= os.popen('kde-config --expandvars --install locale').read().strip()
- env['KDEDOC'] = os.popen('kde-config --expandvars --install html').read().strip()
- env['KDEKCFG'] = os.popen('kde-config --expandvars --install kcfg').read().strip()
- env['KDEXDG'] = os.popen('kde-config --expandvars --install xdgdata-apps').read().strip()
- env['KDEMENU'] = os.popen('kde-config --expandvars --install apps').read().strip()
- env['KDEMIME'] = os.popen('kde-config --expandvars --install mime').read().strip()
- env['KDEICONS'] = os.popen('kde-config --expandvars --install icon').read().strip()
- env['KDESERV'] = os.popen('kde-config --expandvars --install services').read().strip()
-
- env['QTPLUGINS']=os.popen('kde-config --expandvars --install qtplugins').read().strip()
+ env['PREFIX'] = os.popen('tde-config --prefix').read().strip()
+ env['KDEBIN'] = os.popen('tde-config --expandvars --install exe').read().strip()
+ env['KDEAPPS'] = os.popen('tde-config --expandvars --install apps').read().strip()
+ env['KDEDATA'] = os.popen('tde-config --expandvars --install data').read().strip()
+ env['KDEMODULE']= os.popen('tde-config --expandvars --install module').read().strip()
+ env['KDELOCALE']= os.popen('tde-config --expandvars --install locale').read().strip()
+ env['KDEDOC'] = os.popen('tde-config --expandvars --install html').read().strip()
+ env['KDEKCFG'] = os.popen('tde-config --expandvars --install kcfg').read().strip()
+ env['KDEXDG'] = os.popen('tde-config --expandvars --install xdgdata-apps').read().strip()
+ env['KDEMENU'] = os.popen('tde-config --expandvars --install apps').read().strip()
+ env['KDEMIME'] = os.popen('tde-config --expandvars --install mime').read().strip()
+ env['KDEICONS'] = os.popen('tde-config --expandvars --install icon').read().strip()
+ env['KDESERV'] = os.popen('tde-config --expandvars --install services').read().strip()
+
+ env['QTPLUGINS']=os.popen('tde-config --expandvars --install qtplugins').read().strip()
## kde libs and includes
env['KDEINCLUDEPATH']= kdeincludes
if not tdelibs:
- tdelibs = os.popen('kde-config --expandvars --install lib').read().strip()
+ tdelibs = os.popen('tde-config --expandvars --install lib').read().strip()
env['KDELIBPATH']= tdelibs
## qt libs and includes
@@ -30,7 +30,7 @@ def exists(env):
return True
def detect_kde(env):
- """ Detect the qt and kde environment using kde-config mostly """
+ """ Detect the qt and kde environment using tde-config mostly """
prefix = env['ARGS'].get('prefix', None)
execprefix = env['ARGS'].get('execprefix', None)